@@ -13,7 +13,7 @@ from rdfhelpers.rdfhelpers import SPARQLRepository, FocusedGraph, CBDGraph
 from rdfhelpers.templated import graphFrom, identity, mapDict
 from rdfhelpers.templated import Templated, Composable
 from rdfhelpers.constructor import Constructor
-from rdfhelpers.labels import LabelCache, SKOSLabelCache
+from rdfhelpers.labels import LabelCache, SKOSLabelCache, BNodeTracker, BNodeMarker
 from rdfhelpers.gsp import GraphStoreClient
 
 __all__ = [
@@ -25,6 +25,6 @@ __all__ = [
     'graphFrom', 'identity', 'mapDict',
     'Templated', 'Composable',
     'Constructor',
-    'LabelCache', 'SKOSLabelCache',
+    'LabelCache', 'SKOSLabelCache', 'BNodeTracker', 'BNodeMarker',
     'GraphStoreClient'
 ]
