@@ -9,7 +9,7 @@
 import collections
 import itertools
 import re
-
+import logging
 from rdflib import URIRef, Literal
 from rdfhelpers.templated import Templated
 
@@ -127,6 +127,10 @@ class LabelCache:
                 return "{}:{}".format(prefix, name)
         except ValueError:
             return str(uri)
+        except UnboundLocalError as e:
+            # TODO: fix this, somehow...
+            logging.error("This is probably an error in rdflib: {}".format(e))
+            return str(uri)
 
 # SKOS CONCEPT LABEL CACHING
 #
@@ -157,3 +161,33 @@ class SKOSLabelCache(LabelCache):
 
     def listConcepts(self):
         return self._labels.keys()
+
+#
+
+class BNodeMarker:
+    def __init__(self, bnode, i):
+        self.bnode = bnode
+        self.i = i
+
+    def __lt__(self, other):
+        return self.i < other.i
+
+    def __gt__(self, other):
+        return self.i > other.i
+
+class BNodeTracker:
+    def __init__(self, marker_class=BNodeMarker):
+        self.bnodes = dict()
+        self.index = 0
+        self.marker_class = marker_class
+
+    def get(self, bnode):
+        marker = self.bnodes.get(bnode, None)
+        if marker is None:
+            marker = self.marker_class(bnode, self.index)
+            self.index += 1
+            self.bnodes[bnode] = marker
+        return marker
+
+    def seen(self, bnode):
+        return self.bnodes.get(bnode, False) and True
